=======
Whalrus
=======


.. image:: https://img.shields.io/pypi/v/whalrus.svg
        :target: https://pypi.python.org/pypi/whalrus

.. image:: https://img.shields.io/travis/francois-durand/whalrus.svg
        :target: https://travis-ci.org/francois-durand/whalrus

.. image:: https://readthedocs.org/projects/whalrus/badge/?version=latest
        :target: https://whalrus.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/francois-durand/whalrus/shield.svg
     :target: https://pyup.io/repos/github/francois-durand/whalrus/
     :alt: Updates



Which Alternative Represents Us, a package for voting rules


* Free software: GNU General Public License v3
* Documentation: https://whalrus.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

We use the checklist provided by `My Toy Package`_.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`My Toy Package`: https://my-toy-package.readthedocs.io/en/latest/readme.html
